==> gradle-3.2-rc-2-all.zip: gradle-3.2-rc-2/src/tooling-api-builders/org/gradle/tooling/internal/provider/runner/ToolingBuilderServices.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.internal.provider.runner;

import org.gradle.internal.invocation.BuildActionRunner;
import org.gradle.internal.service.ServiceRegistration;
import org.gradle.internal.service.scopes.PluginServiceRegistry;
import org.gradle.launcher.exec.ChainingBuildActionRunner;

import java.util.Arrays;

public class ToolingBuilderServices implements PluginServiceRegistry {
    @Override
    public void registerGlobalServices(ServiceRegistration registration) {

        registration.addProvider(new Object() {
            BuildActionRunner createBuildActionRunner() {
                return new SubscribableBuildActionRunner(new ChainingBuildActionRunner(Arrays.asList(
                                                                new BuildModelActionRunner(),
                                                                new TestExecutionRequestActionRunner(),
                                                                new ClientProvidedBuildActionRunner())));
            }
        });

    }

    public void registerBuildSessionServices(ServiceRegistration registration) {
    }

    @Override
    public void registerBuildServices(ServiceRegistration registration) {
    }

    public void registerGradleServices(ServiceRegistration registration) {
    }

    @Override
    public void registerProjectServices(ServiceRegistration registration) {
    }
}

==> gradle-3.4-all.zip: gradle-3.4/src/tooling-api-builders/org/gradle/tooling/internal/provider/runner/ToolingBuilderServices.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.internal.provider.runner;

import org.gradle.internal.invocation.BuildActionRunner;
import org.gradle.internal.progress.BuildOperationExecutor;
import org.gradle.internal.service.ServiceRegistration;
import org.gradle.internal.service.scopes.PluginServiceRegistry;
import org.gradle.launcher.exec.ChainingBuildActionRunner;

import java.util.Arrays;

public class ToolingBuilderServices implements PluginServiceRegistry {
    @Override
    public void registerGlobalServices(ServiceRegistration registration) {

        registration.addProvider(new Object() {
            BuildActionRunner createBuildActionRunner(BuildOperationExecutor buildOperationExecutor) {
                return new SubscribableBuildActionRunner(
                    new RunAsBuildOperationBuildActionRunner(
                        new ChainingBuildActionRunner(
                            Arrays.asList(
                                new BuildModelActionRunner(),
                                new TestExecutionRequestActionRunner(),
                                new ClientProvidedBuildActionRunner())),
                        buildOperationExecutor));
            }
        });
    }

    public void registerBuildSessionServices(ServiceRegistration registration) {
    }

    @Override
    public void registerBuildServices(ServiceRegistration registration) {
    }

    public void registerGradleServices(ServiceRegistration registration) {
    }

    @Override
    public void registerProjectServices(ServiceRegistration registration) {
    }
}
